Localisation
============

Fill in here.


The start screen shows a list of all supported countries and languages: For
each country its flag is shown, with a list of languages for that country below
it. The countries and languages are sorted by their ISO codes; this is the only
neutral data available and uses a single character set, making it easily
sortable.

